@@ -4,7 +4,6 @@
 #'
 #' Due to package size constraints the data are stored externally (and a working internet connection is required to use the package). Downloaded size is 114 KB.
 #'
-#' @param method Method argument for `download.file()`. The default (i.e. "curl") should be appropriate in most situations.
 #'
 #' @format \code{sf} data frame with 36 rows of 5 variables + geometry
 #'
@@ -18,7 +17,7 @@
 #'
 #' @export
 
-chr_uzemi  <- function(method = "curl") {
+chr_uzemi  <- function() {
 
   remote_path <- 'http://rczechia.jla-data.net/'
 
@@ -40,7 +39,7 @@ chr_uzemi  <- function(method = "curl") {
     } else {
 
       message('RCzechia: downloading remote dataset.')
-      download.file(url = remote_file, destfile = local_file, method = method, quiet = T)
+      curl_download(url = remote_file, destfile = local_file, quiet = T)
     }
   }
 
