@@ -4,8 +4,6 @@
 #'
 #'  Due to package size constraints the data are stored externally (and a working internet connection is required to use the package). Downloaded size is 270 KB.
 #'
-#' @param method Method argument for `download.file()`. The default (i.e. "curl") should be appropriate in most situations.
-#'
 #' @format \code{sf} data frame with 6.258 rows of 14 variables + geometry
 #'
 #' \describe{
@@ -31,7 +29,7 @@
 #'
 #' @export
 
-obce_body <- function(method = "curl") {
+obce_body <- function() {
 
   remote_path <- 'http://rczechia.jla-data.net/'
 
@@ -53,8 +51,9 @@ obce_body <- function(method = "curl") {
     } else {
 
       message('RCzechia: downloading remote dataset.')
-      download.file(url = remote_file, destfile = local_file, method = method, quiet = T)
-    }
+      curl_download(url = remote_file, destfile = local_file, quiet = T)
+
+      }
   }
 
   local_df <- readRDS(local_file)
