@@ -4,8 +4,6 @@
 #'
 #' Due to package size constraints the data are stored externally (and a working internet connection is required to use the package). Downloaded size is 9 MB (so use with caution, and patience).
 #'
-#' @param method Method argument for `download.file()`. The default (i.e. "curl") should be appropriate in most situations.
-#'
 #' @format \code{sf} data frame with 206 rows of 10 variables + geometry
 #'
 #' \describe{
@@ -28,7 +26,7 @@
 #'
 #' @export
 
-orp_polygony <- function(method = "curl") {
+orp_polygony <- function() {
 
   remote_path <- 'http://rczechia.jla-data.net/'
 
@@ -50,8 +48,9 @@ orp_polygony <- function(method = "curl") {
     } else {
 
       message('RCzechia: downloading remote dataset.')
-      download.file(url = remote_file, destfile = local_file, method = method, quiet = T)
-    }
+      curl_download(url = remote_file, destfile = local_file, quiet = T)
+
+      }
   }
 
   local_df <- readRDS(local_file)
