@@ -5,7 +5,6 @@
 #' Due to package size constraints the data are stored externally (and a working internet connection is required to use the package). Downloaded size of high resolution shapefile is 949.7 KB.
 #'
 #' @param resolution Should the function return high or low resolution shapefile? Allowed values are "high" (default) and "low". This parameter affects only the geometry column, all other fields remain the same.
-#' @param method Method argument for `download.file()`. The default (i.e. "curl") should be appropriate in most situations.
 #'
 #' @format \code{sf} data frame with 1 row of 1 variable + geometry:
 #'
@@ -21,7 +20,7 @@
 #' @export
 
 
-republika <- function(resolution = "high", method = "curl") {
+republika <- function(resolution = "high") {
 
   remote_path <- 'http://rczechia.jla-data.net/'
 
@@ -51,8 +50,9 @@ republika <- function(resolution = "high", method = "curl") {
       } else {
 
         message('RCzechia: downloading remote dataset.')
-        download.file(url = remote_file, destfile = local_file, method = method, quiet = T)
-      }
+        curl_download(url = remote_file, destfile = local_file, quiet = T)
+
+        }
     }
 
     local_df <- readRDS(local_file)
